netapp_ontap.models.firmware_update_progress_state API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_update_progress_state`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareUpdateProgressStateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareUpdateProgressState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `attempts GET`

    The attempts field of the firmware_update_progress_state.

    Example: 3

  `code GET`

    Code corresponding to the status message.

    Example: 2228325

  `message GET`

    Error message returned when a cluster firmware update job fails.

    Example: Cannot open local staging ZIP file disk_firmware.zip

  `status GET`

    The status field of the firmware_update_progress_state.

    Valid choices:

    - idle
    - working
    - complete
    - failed
    - waiting_to_retry
  `worker_node GET`

    The worker_node field of the firmware_update_progress_state.